package Lire::Config::IntegerSpec;

use strict;

=pod

=head1 Lire::Config::IntegerSpec

Type that represents an integer number. Values of this type are simple
integer numbers with a range of -2147483648 to 2147483647.

=cut

use base qw/Lire::Config::ScalarSpec/;

sub is_valid {
    my ( $self, $val ) = @_;

    return !$self->required() unless defined $val;

    return scalar $val =~ /^-?[0-9_]+$/;
}

sub normalize {
    my ( $self, $val ) = @_;

    return undef unless defined $val;

    no warnings 'numeric';
    return int($val);
}

1;
__END__

=pod

=head1 VERSION

$Id: IntegerSpec.pm,v 1.4 2006/07/23 13:16:30 vanbaal Exp $

=head1 AUTHORS

Francis J. Lacoste <flacoste@logreport.org>
Wessel Dankers <wsl@logreport.org>
Wolfgang Sourdeau <wolfgang@logreport.org>

=head1 COPYRIGHT

Copyright (C) 2002-2004  Stichting LogReport Foundation LogReport@LogReport.org

This file is part of Lire.

Lire is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program (see COPYING); if not, check with
http://www.gnu.org/copyleft/gpl.html.

=cut
